==> xlniuxdata-vipgame-1.0.33-sources.jar: com/xunlei/niux/data/vipgame/dto/vic/CustomerWarningLostPayDTO.java <==
package com.xunlei.niux.data.vipgame.dto.vic;

public class CustomerWarningLostPayDTO {
    private String uid;
    private Integer vipGrade;
    private String lastLoginTime;
    private String lastPayTime;
    private Long lastModifyAmt;
    private String payGameId;
    private String lastCaller;
    private String lastCallTime;
    private String customerService;
    private String lostPay;
    private String firstTreat;
    private String firstTreatResult;
    private String secondTreat;
    private String secondTreatResult;
    private Integer lostLoginDays;
    private Integer lostPayDays;

    public String getCustomerService() {
        return customerService;
    }

    public void setCustomerService(String customerService) {
        this.customerService = customerService;
    }

    public String getFirstTreat() {
        return firstTreat;
    }

    public void setFirstTreat(String firstTreat) {
        this.firstTreat = firstTreat;
    }

    public String getFirstTreatResult() {
        return firstTreatResult;
    }

    public void setFirstTreatResult(String firstTreatResult) {
        this.firstTreatResult = firstTreatResult;
    }

    public String getLastCaller() {
        return lastCaller;
    }

    public void setLastCaller(String lastCaller) {
        this.lastCaller = lastCaller;
    }

    public String getLastCallTime() {
        return lastCallTime;
    }

    public void setLastCallTime(String lastCallTime) {
        this.lastCallTime = lastCallTime;
    }

    public String getLastLoginTime() {
        return lastLoginTime;
    }

    public void setLastLoginTime(String lastLoginTime) {
        this.lastLoginTime = lastLoginTime;
    }

    public Long getLastModifyAmt() {
        return lastModifyAmt;
    }

    public void setLastModifyAmt(Long lastModifyAmt) {
        this.lastModifyAmt = lastModifyAmt;
    }

    public String getLastPayTime() {
        return lastPayTime;
    }

    public void setLastPayTime(String lastPayTime) {
        this.lastPayTime = lastPayTime;
    }

    public Integer getLostLoginDays() {
        return lostLoginDays;
    }

    public void setLostLoginDays(Integer lostLoginDays) {
        this.lostLoginDays = lostLoginDays;
    }

    public String getLostPay() {
        return lostPay;
    }

    public void setLostPay(String lostPay) {
        this.lostPay = lostPay;
    }

    public Integer getLostPayDays() {
        return lostPayDays;
    }

    public void setLostPayDays(Integer lostPayDays) {
        this.lostPayDays = lostPayDays;
    }

    public String getPayGameId() {
        return payGameId;
    }

    public void setPayGameId(String payGameId) {
        this.payGameId = payGameId;
    }

    public String getSecondTreat() {
        return secondTreat;
    }

    public void setSecondTreat(String secondTreat) {
        this.secondTreat = secondTreat;
    }

    public String getSecondTreatResult() {
        return secondTreatResult;
    }

    public void setSecondTreatResult(String secondTreatResult) {
        this.secondTreatResult = secondTreatResult;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public Integer getVipGrade() {
        return vipGrade;
    }

    public void setVipGrade(Integer vipGrade) {
        this.vipGrade = vipGrade;
    }
}

==> xlniuxdata-vipgame-1.0.33-20151110.124833-15-sources.jar: com/xunlei/niux/data/vipgame/dto/vic/CustomerWarningLostPayDTO.java <==
package com.xunlei.niux.data.vipgame.dto.vic;

public class CustomerWarningLostPayDTO {
    private String uid;
    private Integer vipGrade;
    private String lastLoginTime;
    private String lastPayTime;
    private Long lastModifyAmt;
    private String payGameId;
    private String lastCaller;
    private String lastCallTime;
    private String customerService;
    private String lostPay;
    private String firstTreat;
    private String firstTreatResult;
    private String secondTreat;
    private String secondTreatResult;
    private Integer lostLoginDays;
    private Integer lostPayDays;
    private Integer loginPayType;

    public Integer getLoginPayType() {
        return loginPayType;
    }

    public void setLoginPayType(Integer loginPayType) {
        this.loginPayType = loginPayType;
    }

    public String getCustomerService() {
        return customerService;
    }

    public void setCustomerService(String customerService) {
        this.customerService = customerService;
    }

    public String getFirstTreat() {
        return firstTreat;
    }

    public void setFirstTreat(String firstTreat) {
        this.firstTreat = firstTreat;
    }

    public String getFirstTreatResult() {
        return firstTreatResult;
    }

    public void setFirstTreatResult(String firstTreatResult) {
        this.firstTreatResult = firstTreatResult;
    }

    public String getLastCaller() {
        return lastCaller;
    }

    public void setLastCaller(String lastCaller) {
        this.lastCaller = lastCaller;
    }

    public String getLastCallTime() {
        return lastCallTime;
    }

    public void setLastCallTime(String lastCallTime) {
        this.lastCallTime = lastCallTime;
    }

    public String getLastLoginTime() {
        return lastLoginTime;
    }

    public void setLastLoginTime(String lastLoginTime) {
        this.lastLoginTime = lastLoginTime;
    }

    public Long getLastModifyAmt() {
        return lastModifyAmt;
    }

    public void setLastModifyAmt(Long lastModifyAmt) {
        this.lastModifyAmt = lastModifyAmt;
    }

    public String getLastPayTime() {
        return lastPayTime;
    }

    public void setLastPayTime(String lastPayTime) {
        this.lastPayTime = lastPayTime;
    }

    public Integer getLostLoginDays() {
        return lostLoginDays;
    }

    public void setLostLoginDays(Integer lostLoginDays) {
        this.lostLoginDays = lostLoginDays;
    }

    public String getLostPay() {
        return lostPay;
    }

    public void setLostPay(String lostPay) {
        this.lostPay = lostPay;
    }

    public Integer getLostPayDays() {
        return lostPayDays;
    }

    public void setLostPayDays(Integer lostPayDays) {
        this.lostPayDays = lostPayDays;
    }

    public String getPayGameId() {
        return payGameId;
    }

    public void setPayGameId(String payGameId) {
        this.payGameId = payGameId;
    }

    public String getSecondTreat() {
        return secondTreat;
    }

    public void setSecondTreat(String secondTreat) {
        this.secondTreat = secondTreat;
    }

    public String getSecondTreatResult() {
        return secondTreatResult;
    }

    public void setSecondTreatResult(String secondTreatResult) {
        this.secondTreatResult = secondTreatResult;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public Integer getVipGrade() {
        return vipGrade;
    }

    public void setVipGrade(Integer vipGrade) {
        this.vipGrade = vipGrade;
    }
}
